==> ejc-bfyjerp-impl-3.0.0-20250117.092506-106-sources.jar: com/ejianc/business/project/bean/ProjectRegisterFileEntity.java <==
package com.ejianc.business.project.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目基本信息管理-项目资料子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_project_register_file")
public class ProjectRegisterFileEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="detail_file_type")
    private String detailFileType; // 文件类型
    @TableField(value="detail_file_form")
    private String detailFileForm; // 文件形式：原件，复印件
    @TableField(value="detail_file_position")
    private String detailFilePosition; // 文件位置
    @TableField(value="detail_file_id")
    private String detailFileId; // 文件id
    @TableField(value="detail_file_name")
    private String detailFileName; // 文件名称
    @TableField(value="doc_type")
    private String docType; // 资料类型：0-项目资料，1-其他盖章资料
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDetailFileType() {
        return detailFileType;
    }

    public void setDetailFileType(String detailFileType) {
        this.detailFileType = detailFileType;
    }
    public String getDetailFileForm() {
        return detailFileForm;
    }

    public void setDetailFileForm(String detailFileForm) {
        this.detailFileForm = detailFileForm;
    }
    public String getDetailFilePosition() {
        return detailFilePosition;
    }

    public void setDetailFilePosition(String detailFilePosition) {
        this.detailFilePosition = detailFilePosition;
    }
    public String getDetailFileId() {
        return detailFileId;
    }

    public void setDetailFileId(String detailFileId) {
        this.detailFileId = detailFileId;
    }
    public String getDetailFileName() {
        return detailFileName;
    }

    public void setDetailFileName(String detailFileName) {
        this.detailFileName = detailFileName;
    }
    public String getDocType() {
        return docType;
    }

    public void setDocType(String docType) {
        this.docType = docType;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250724.083026-258-sources.jar: com/ejianc/business/project/bean/ProjectRegisterFileEntity.java <==
package com.ejianc.business.project.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目基本信息管理-项目资料子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_project_register_file")
public class ProjectRegisterFileEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="detail_file_type")
    private String detailFileType; // 文件类型
    @TableField(value="detail_file_form")
    private String detailFileForm; // 文件形式：原件，复印件
    @TableField(value="detail_file_position")
    private String detailFilePosition; // 文件位置
    @TableField(value="detail_file_id")
    private String detailFileId; // 文件id
    @TableField(value="detail_file_name")
    private String detailFileName; // 文件名称
    @TableField(value="doc_type")
    private String docType; // 资料类型：0-项目资料，1-其他盖章资料
    @TableField(value="copies")
    private Integer copies; // 份数


    public Integer getCopies() {
        return copies;
    }

    public void setCopies(Integer copies) {
        this.copies = copies;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDetailFileType() {
        return detailFileType;
    }

    public void setDetailFileType(String detailFileType) {
        this.detailFileType = detailFileType;
    }
    public String getDetailFileForm() {
        return detailFileForm;
    }

    public void setDetailFileForm(String detailFileForm) {
        this.detailFileForm = detailFileForm;
    }
    public String getDetailFilePosition() {
        return detailFilePosition;
    }

    public void setDetailFilePosition(String detailFilePosition) {
        this.detailFilePosition = detailFilePosition;
    }
    public String getDetailFileId() {
        return detailFileId;
    }

    public void setDetailFileId(String detailFileId) {
        this.detailFileId = detailFileId;
    }
    public String getDetailFileName() {
        return detailFileName;
    }

    public void setDetailFileName(String detailFileName) {
        this.detailFileName = detailFileName;
    }
    public String getDocType() {
        return docType;
    }

    public void setDocType(String docType) {
        this.docType = docType;
    }
    
}
